gftp/command/feat

This module exposes the FEAT command types

Types

The features supported by the server, as returned by the FEAT command.

A feat has a key representing the name of the feature, and an optional value representing any parameters for that feature.

pub type Features =
  dict.Dict(String, option.Option(String))

Values

pub fn is_last_line(line: String) -> Bool

Returns whether the given line is the last line of a FEAT response, which starts with “211 “.

pub fn parse_features(
  lines: List(String),
) -> Result(
  dict.Dict(String, option.Option(String)),
  result.FtpError,
)

Parses the lines of a FEAT response into a Features dictionary.

Search Document