gftp/response

FTP Response returned by the server.

Types

The Response type represents a response from the FTP server. It contains a status code and a message.

pub type Response {
  Response(code: status.Status, message: BitArray)
}

Constructors

Values

pub fn describe(response: Response) -> String

The describe function takes a Response and returns a human-readable string describing the response.

pub fn to_string(response: Response) -> Result(String, Nil)
Search Document